update_engine: Rename "chromeos" -> "brillo" in include paths and namespaces

libchromeos is transitioning to libbrillo and chromeos namespaces
and include directory is changing to brillo.

Bug: 24872993
Change-Id: I770659a95be380a50fe3b2ba9f91d65818f40945
diff --git a/daemon.h b/daemon.h
index 8eb1102..01961bc 100644
--- a/daemon.h
+++ b/daemon.h
@@ -20,7 +20,7 @@
 #include <memory>
 #include <string>
 
-#include <chromeos/daemons/dbus_daemon.h>
+#include <brillo/daemons/dbus_daemon.h>
 
 #include "update_engine/certificate_checker.h"
 #include "update_engine/dbus_service.h"
@@ -29,7 +29,7 @@
 
 namespace chromeos_update_engine {
 
-class UpdateEngineDaemon : public chromeos::DBusDaemon {
+class UpdateEngineDaemon : public brillo::DBusDaemon {
  public:
   UpdateEngineDaemon() = default;
 
@@ -42,7 +42,7 @@
   // initialization.
   void OnDBusRegistered(bool succeeded);
 
   // The Subprocess singleton class requires a chromeos::MessageLoop in the
   // current thread, so we need to initialize it from this class instead of
   // the main() function.
   Subprocess subprocess_;
@@ -42,7 +42,7 @@
   void OnDBusRegistered(bool succeeded);
 
-  // The Subprocess singleton class requires a chromeos::MessageLoop in the
+  // The Subprocess singleton class requires a brillo::MessageLoop in the
   // current thread, so we need to initialize it from this class instead of
   // the main() function.